package de.java2html.eclipse.preferences;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.ArrayList;

import org.eclipse.jface.preference.ColorSelector;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;

import de.java2html.options.JavaSourceStyleEntry;

/**
 * @author Markus Gebhard
 */
public class JavaSourceStyleEntryControl implements SelectionListener {
  private Button cbBold;
  private Button cbItalic;
  private ColorSelector colorSelector;
  private ArrayList listeners;

  public Control createControl(Composite comp) {
    Composite comp1 = new Composite(comp, SWT.NONE);
    comp1.setLayout(new RowLayout(SWT.VERTICAL));

    Composite comp2 = new Composite(comp1, SWT.NONE);
    GridLayout gridLayout2 = new GridLayout(2, false);
    gridLayout2.marginHeight = 0;
    gridLayout2.marginWidth = 0;
    comp2.setLayout(gridLayout2);
    Label colorSelectorLabel = new Label(comp2, SWT.NONE);
    colorSelectorLabel.setText("Color:");
    colorSelector = new ColorSelector(comp2);
    colorSelector.getButton().addSelectionListener(this);

    cbBold = new Button(comp1, SWT.CHECK);
    cbBold.setText("&Bold");
    cbBold.addSelectionListener(this);// {

    cbItalic = new Button(comp1, SWT.CHECK);
    cbItalic.setText("&Italic");
    cbItalic.addSelectionListener(this);

    return comp1;
  }

  public void widgetSelected(SelectionEvent e) {
    fire(new PropertyChangeEvent(this, "JavaSourceStyleEntry", null, null));
  }

  public JavaSourceStyleEntry getJavaSourceStyleEntry() {
    boolean bold = cbBold.getSelection();
    boolean italic = cbItalic.getSelection();
    de.java2html.util.RGB color = swtRgbToJava2HtmlRgb(colorSelector.getColorValue());
    return new JavaSourceStyleEntry(color, bold, italic);
  }

  public void widgetDefaultSelected(SelectionEvent e) {
    //nothing to do
  }

  public void setJavaSourceStyleEntry(JavaSourceStyleEntry javaSourceStyleEntry) {
    cbBold.setSelection(javaSourceStyleEntry.isBold());
    cbItalic.setSelection(javaSourceStyleEntry.isItalic());
    colorSelector.setColorValue(java2htmlRgbToSwtRgb(javaSourceStyleEntry.getColor()));
  }

  private static RGB java2htmlRgbToSwtRgb(de.java2html.util.RGB color) {
    return new RGB(color.getRed(), color.getGreen(), color.getBlue());
  }

  private static de.java2html.util.RGB swtRgbToJava2HtmlRgb(RGB rgb) {
    return new de.java2html.util.RGB(rgb.red, rgb.green, rgb.blue);
  }

  public synchronized void addPropertyChangeListener(PropertyChangeListener listener) {
    if (listeners == null) {
      listeners = new ArrayList();
    }
    listeners.add(listener);
  }

  public synchronized void removePropertyChangeListener(PropertyChangeListener listener) {
    if (listeners == null) {
      return;
    }
    listeners.remove(listener);
  }

  private synchronized void fire(PropertyChangeEvent event) {
    if (listeners == null) {
      return;
    }
    for (int i = 0; i < listeners.size(); ++i) {
      ((PropertyChangeListener) listeners.get(i)).propertyChange(event);
    }
  }
}